easy_geotool - an easy tool for geospatial data processing
====

easy_geotool is an open source Apache licensed  library for raster and vector geospatial data processing based on rasterio and geopandas.